@@ -21,29 +21,28 @@ using OpenQA.Selenium.Interactions;
 using System;
 using System.Collections.Generic;
 
-namespace OpenQA.Selenium
+namespace OpenQA.Selenium;
+
+/// <summary>
+/// Interface allowing execution of W3C Specification-compliant actions.
+/// </summary>
+public interface IActionExecutor
 {
     /// <summary>
-    /// Interface allowing execution of W3C Specification-compliant actions.
+    /// Gets a value indicating whether this object is a valid action executor.
     /// </summary>
-    public interface IActionExecutor
-    {
-        /// <summary>
-        /// Gets a value indicating whether this object is a valid action executor.
-        /// </summary>
-        bool IsActionExecutor { get; }
+    bool IsActionExecutor { get; }
 
-        /// <summary>
-        /// Performs the specified list of actions with this action executor.
-        /// </summary>
-        /// <param name="actionSequenceList">The list of action sequences to perform.</param>
-        /// <exception cref="ArgumentNullException">If <paramref name="actionSequenceList"/> is <see langword="null"/>.</exception>
-        /// <exception cref="ArgumentException">If an element in <paramref name="actionSequenceList"/> is <see langword="null"/>.</exception>
-        void PerformActions(IList<ActionSequence> actionSequenceList);
+    /// <summary>
+    /// Performs the specified list of actions with this action executor.
+    /// </summary>
+    /// <param name="actionSequenceList">The list of action sequences to perform.</param>
+    /// <exception cref="ArgumentNullException">If <paramref name="actionSequenceList"/> is <see langword="null"/>.</exception>
+    /// <exception cref="ArgumentException">If an element in <paramref name="actionSequenceList"/> is <see langword="null"/>.</exception>
+    void PerformActions(IList<ActionSequence> actionSequenceList);
 
-        /// <summary>
-        /// Resets the input state of the action executor.
-        /// </summary>
-        void ResetInputState();
-    }
+    /// <summary>
+    /// Resets the input state of the action executor.
+    /// </summary>
+    void ResetInputState();
 }
