@@ -20,15 +20,14 @@
 using OpenQA.Selenium.Firefox;
 using System;
 
-namespace OpenQA.Selenium.Remote
+namespace OpenQA.Selenium.Remote;
+
+// This is a simple wrapper class to create a RemoteWebDriver that
+// has no parameters in the constructor.
+public class FirefoxRemoteWebDriver : RemoteWebDriver
 {
-    // This is a simple wrapper class to create a RemoteWebDriver that
-    // has no parameters in the constructor.
-    public class FirefoxRemoteWebDriver : RemoteWebDriver
+    public FirefoxRemoteWebDriver()
+        : base(new Uri("http://127.0.0.1:6000/wd/hub/"), new FirefoxOptions())
     {
-        public FirefoxRemoteWebDriver()
-            : base(new Uri("http://127.0.0.1:6000/wd/hub/"), new FirefoxOptions())
-        {
-        }
     }
 }
